google-cloud-platform-core 2.74.0 API

Packages 
Package Description
org.apache.beam.sdk.extensions.gcp.auth
Defines classes related to interacting with Credentials for pipeline creation and execution containing Google Cloud Platform components.
org.apache.beam.sdk.extensions.gcp.options
Defines PipelineOptions for configuring pipeline execution for Google Cloud Platform components.
org.apache.beam.sdk.extensions.gcp.storage
Defines IO connectors for Google Cloud Storage.
org.apache.beam.sdk.extensions.gcp.util
Defines Google Cloud Platform component utilities that can be used by Beam runners.
org.apache.beam.sdk.extensions.gcp.util.channels
Package contains java channel wrappers used with GCS.
org.apache.beam.sdk.extensions.gcp.util.gcsfs
Defines utilities used to interact with Google Cloud Storage.